@@ -54,7 +54,11 @@ namespace Spotify
 
             void setPlaybackPos(qint64 pos);
 
-            void setBufferingPos(qint64 pos);
+            qint64 getPlaybackPos();
+
+            void setBufferingPos(qint32 pos);
+
+            qint32 getBufferingPos();
 
             void setPlaying(bool playing);
 
@@ -73,24 +77,6 @@ namespace Spotify
              */
             bool isValid() { return m_valid; }
 
-            bool m_ProcessEvents;
-
-            bool m_bPlaylistsLoading; //TRUE in case playlist loading is in progress
-
-            bool m_bStopPlaylistLoading; //TRUE in case playlist loading should be stopped (interrupted)
-
-            bool m_DisableNotifyThread;
-
-            bool m_preBufActive; //true if track pre-buffering is enabled
-
-            QTimer *m_pProcEvtTimer;
-
-
-
-            /**
-             * Audio playback thread
-             */
-            PlaybackThread* m_pAudioThread;
 
             /**
              * Fetches the currently logged in user.
@@ -500,6 +486,24 @@ namespace Spotify
 
             bool m_playing;
 
+            bool m_ProcessEvents;
+
+            bool m_bPlaylistsLoading; //TRUE in case playlist loading is in progress
+
+            bool m_bStopPlaylistLoading; //TRUE in case playlist loading should be stopped (interrupted)
+
+            bool m_DisableNotifyThread;
+
+            bool m_preBufActive; //true if track pre-buffering is enabled
+
+            QTimer *m_pProcEvtTimer;
+
+
+            /**
+             * Audio playback thread
+             */
+            PlaybackThread* m_pAudioThread;
+
             // For mapping sp_playlist pointers to Spotify::Playlist pointers
             QHash< sp_playlist*, Spotify::Playlist* > m_playlistHash;
 
